<?php

namespace Tesr\Test1\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Tesr\Test1\Models\Customermaster;

class CustomermasterPolicy
{

    /**
     * Determine if the given user can view the customermaster.
     *
     * @param UserPolicyInterface $authUser
     * @param Customermaster $customermaster
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Customermaster $customermaster)
    {
        if ($authUser->canDo('test1.customermaster.view') && $authUser->isAdmin()) {
            return true;
        }

        return $customermaster->user_id == user_id() && $customermaster->user_type == user_type();
    }

    /**
     * Determine if the given user can create a customermaster.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('test1.customermaster.create');
    }

    /**
     * Determine if the given user can update the given customermaster.
     *
     * @param UserPolicyInterface $authUser
     * @param Customermaster $customermaster
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Customermaster $customermaster)
    {
        if ($authUser->canDo('test1.customermaster.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $customermaster->user_id == user_id() && $customermaster->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given customermaster.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Customermaster $customermaster)
    {
        return $customermaster->user_id == user_id() && $customermaster->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given customermaster.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Customermaster $customermaster)
    {
        if ($authUser->canDo('test1.customermaster.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given customermaster.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Customermaster $customermaster)
    {
        if ($authUser->canDo('test1.customermaster.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
