<?php

namespace Tesr\Test1\Workflow;

use Tesr\Test1\Models\Customermaster;
use Validator;

class CustomermasterValidator
{

    /**
     * Determine if the given customermaster is valid for complete status.
     *
     * @param Customermaster $customermaster
     *
     * @return bool / Validator
     */
    public function complete(Customermaster $customermaster)
    {
        return Validator::make($customermaster->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given customermaster is valid for verify status.
     *
     * @param Customermaster $customermaster
     *
     * @return bool / Validator
     */
    public function verify(Customermaster $customermaster)
    {
        return Validator::make($customermaster->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given customermaster is valid for approve status.
     *
     * @param Customermaster $customermaster
     *
     * @return bool / Validator
     */
    public function approve(Customermaster $customermaster)
    {
        return Validator::make($customermaster->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given customermaster is valid for publish status.
     *
     * @param Customermaster $customermaster
     *
     * @return bool / Validator
     */
    public function publish(Customermaster $customermaster)
    {
        return Validator::make($customermaster->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given customermaster is valid for archive status.
     *
     * @param Customermaster $customermaster
     *
     * @return bool / Validator
     */
    public function archive(Customermaster $customermaster)
    {
        return Validator::make($customermaster->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given customermaster is valid for unpublish status.
     *
     * @param Customermaster $customermaster
     *
     * @return bool / Validator
     */
    public function unpublish(Customermaster $customermaster)
    {
        return Validator::make($customermaster->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
